@@ -1,17 +1,26 @@
-"""Utilities for importing CSV observation data from the
-`iNaturalist bulk export tool <https://www.inaturalist.org/observations/export>`_ and processing it
-into a format that can be combined with JSON observation data from the iNaturalist API.
+"""Import CSV observation data from the
+`iNaturalist bulk export tool <https://www.inaturalist.org/observations/export>`_.
+
+Example::
+
+    >>> load_csv_exports('~/Downloads/my_observations.csv')
 """
 import re
+from csv import DictReader
 from glob import glob
 from logging import getLogger
-from os.path import basename, expanduser
-from typing import List
+from os.path import basename
+from pathlib import Path
+from typing import TYPE_CHECKING, List
 
+from pyinaturalist import JsonResponse
 from pyinaturalist.constants import RANKS
 from pyinaturalist.converters import try_datetime
 
-from .converters import to_dataframe
+from .converters import PathOrStr, to_dataframe
+
+if TYPE_CHECKING:
+    from pandas import DataFrame
 
 # Explicit datatypes for columns loaded from CSV
 DTYPES = {
@@ -79,9 +88,8 @@ PHOTO_ID_PATTERN = re.compile(r'.*photos/(.*)/.*\.(\w+)')
 logger = getLogger(__name__)
 
 
-# TODO: Do this with tablib instead of pandas?
-# OR: use pandas if installed, otherwise fallback to tablib?
-def load_csv_exports(*file_paths: str):
+# TODO: Use pandas if installed, otherwise fallback to tablib?
+def load_csv_exports(*file_paths: PathOrStr) -> 'DataFrame':
     """Read one or more CSV files from ithe Nat export tool into a dataframe
 
     Args:
@@ -89,25 +97,37 @@ def load_csv_exports(*file_paths: str):
     """
     import pandas as pd
 
-    resolved_paths = resolve_file_paths(*file_paths)
+    resolved_paths = _resolve_file_paths(*file_paths)
     logger.info(
         f'Reading {len(resolved_paths)} exports:\n'
         + '\n'.join([f'\t{basename(f)}' for f in resolved_paths])
     )
 
     df = pd.concat((pd.read_csv(f) for f in resolved_paths), ignore_index=True)
-    return format_export(df)
+    return _format_export(df)
 
 
-def resolve_file_paths(*file_paths: str) -> List[str]:
+def is_csv_export(file_path: PathOrStr) -> bool:
+    """Check if a file is a CSV export from the iNaturalist export tool (to distinguish from
+    converted API results)
+    """
+    with open(file_path) as f:
+        reader = DictReader(f)
+        fields = next(reader).keys()
+    # Just check for a field name that's only in the export and not in API results
+    return 'captive_cultivated' in fields
+
+
+def _resolve_file_paths(*file_paths: PathOrStr) -> List[Path]:
     """Given file paths and/or glob patterns, return a list of resolved file paths"""
-    resolved_paths = [p for p in file_paths if '*' not in p]
-    for path in [p for p in file_paths if '*' in p]:
+    file_path_strs = [str(p) for p in file_paths]
+    resolved_paths = [p for p in file_path_strs if '*' not in p]
+    for path in [p for p in file_path_strs if '*' in p]:
         resolved_paths.extend(glob(path))
-    return [expanduser(p) for p in resolved_paths]
+    return [Path(p).expanduser() for p in resolved_paths]
 
 
-def format_columns(df):
+def _format_columns(df: 'DataFrame') -> 'DataFrame':
     """Some datatype conversions that apply to both CSV exports and API response data"""
     # Convert to expected datatypes
     for col, dtype in DTYPES.items():
@@ -119,22 +139,22 @@ def format_columns(df):
     return df.fillna('')
 
 
-def format_response(response):
+def _format_response(response: JsonResponse) -> 'DataFrame':
     """Convert and format API response data into a dataframe"""
     df = to_dataframe(response['results'])
     df['photo.url'] = df['photos'].apply(lambda x: x[0]['url'])
     df['photo.id'] = df['photos'].apply(lambda x: x[0]['id'])
-    df = format_columns(df)
+    df = _format_columns(df)
     return df
 
 
-def format_export(df):
+def _format_export(df: 'DataFrame') -> 'DataFrame':
     """Format an exported CSV file to be more consistent with API response format"""
     logger.info(f'Formatting {len(df)} observation records')
 
     # Rename, convert, and drop selected columns
     df = df.rename(columns={col: _rename_column(col) for col in sorted(df.columns)})
-    df = format_columns(df)
+    df = _format_columns(df)
 
     # Convert datetimes
     df['observed_on'] = df['observed_on_string'].apply(lambda x: try_datetime(x) or x)
@@ -157,14 +177,6 @@ def format_export(df):
     return df
 
 
-def _fixna(df):
-    """Fix null values of the wrong type"""
-    for col, dtype in DTYPES.items():
-        if col in df:
-            df[col] = df[col].apply(lambda x: x or dtype())
-    return df
-
-
 def _get_min_rank(series):
     for rank in RANKS:
         if series.get(f'taxon.{rank}'):
